![POLITICO](https://rawgithub.com/The-Politico/src/master/images/logo/badge.png)

# django-slackchat-serializer

A pluggable Django app to serialize chat messages in a Slack channel.

Works as the bridge between Slack and your CMS or any custom renderer to publish your slackchats.

[Read the docs.](http://django-slackchat-serializer.readthedocs.io/en/latest/index.html)
